@@ -629,7 +629,7 @@ static char *appfs_get_homedir(uid_t fsuid) {
 #if UINT_MAX < 4294967295
 #error Integer size is too small 
 #endif
-static unsigned long long appfs_get_path_inode(const char *path) {
+static unsigned long long appfs_get_path_inode(const char *path, int uid) {
 	unsigned int retval;
 	const unsigned char *p;
 
@@ -645,6 +645,11 @@ static unsigned long long appfs_get_path_inode(const char *path) {
 #endif
 	}
 
+	if (uid >= 0) {
+		retval += uid;
+		retval++;
+	}
+
 	return(retval);
 }
 
@@ -666,7 +671,7 @@ static int appfs_get_path_info_cache_get(const char *path, uid_t uid, struct app
 	}
 
 	if (appfs_path_info_cache != NULL) {
-		hash_idx = (appfs_get_path_inode(path) + uid) % appfs_path_info_cache_size;
+		hash_idx = (appfs_get_path_inode(path, uid)) % appfs_path_info_cache_size;
 
 		if (appfs_path_info_cache[hash_idx]._cache_path != NULL) {
 			if (strcmp(appfs_path_info_cache[hash_idx]._cache_path, path) == 0 && appfs_path_info_cache[hash_idx]._cache_uid == uid) {
@@ -709,7 +714,7 @@ static void appfs_get_path_info_cache_add(const char *path, uid_t uid, struct ap
 		appfs_path_info_cache = calloc(appfs_path_info_cache_size, sizeof(*appfs_path_info_cache));
 	}
 
-	hash_idx = (appfs_get_path_inode(path) + uid) % appfs_path_info_cache_size;
+	hash_idx = (appfs_get_path_inode(path, uid)) % appfs_path_info_cache_size;
 
 	if (appfs_path_info_cache[hash_idx]._cache_path != NULL) {
 		free(appfs_path_info_cache[hash_idx]._cache_path);
@@ -742,7 +747,7 @@ static void appfs_get_path_info_cache_rm(const char *path, uid_t uid) {
 	}
 
 	if (appfs_path_info_cache != NULL) {
-		hash_idx = (appfs_get_path_inode(path) + uid) % appfs_path_info_cache_size;
+		hash_idx = (appfs_get_path_inode(path, uid)) % appfs_path_info_cache_size;
 
 		if (appfs_path_info_cache[hash_idx]._cache_path != NULL) {
 			free(appfs_path_info_cache[hash_idx]._cache_path);
@@ -913,7 +918,6 @@ static int appfs_get_path_info(const char *path, struct appfs_pathinfo *pathinfo
 	}
 
 	pathinfo->packaged = 0;
-	pathinfo->inode = appfs_get_path_inode(path);
 
 	appfs_call_libtcl(
 		attr_value_str = Tcl_GetString(attr_value);
@@ -1013,6 +1017,12 @@ static int appfs_get_path_info(const char *path, struct appfs_pathinfo *pathinfo
 		Tcl_Release(interp);
 	)
 
+	if (pathinfo->packaged) {
+		pathinfo->inode = appfs_get_path_inode(path, -1);
+	} else {
+		pathinfo->inode = appfs_get_path_inode(path, fsuid);
+	}
+
 	if (retval == 0) {
 		appfs_get_path_info_cache_add(path, fsuid, pathinfo);
 	} else {
